pub enum DeviceIteratorRequest {
GetNext {
responder: DeviceIteratorGetNextResponder,
},
}Expand description
Protocol for iterating over the initial set of active devices.
This iterator is returned upon registering a listener and is used to bootstrap the client’s state with the devices that are already present.
Variants
GetNext
Returns the next batch of active devices.
Returns an empty vector when all existing devices have been iterated
through. The client should then close this channel and rely on the
DeviceListener for subsequent events.
Fields

responder: DeviceIteratorGetNextResponderImplementations
Sourceimpl DeviceIteratorRequest
impl DeviceIteratorRequest
pub fn into_get_next(self) -> Option<DeviceIteratorGetNextResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL