pub enum DeviceListenerRegistryRequest {
RegisterListener {
listener: ClientEnd<DeviceListenerMarker>,
responder: DeviceListenerRegistryRegisterListenerResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: DeviceListenerRegistryControlHandle,
method_type: MethodType,
},
}Expand description
Registry service that allows clients to monitor input device changes.
Variants
RegisterListener
Registers a listener to receive future device change events.
Returns a DeviceIterator which the client MUST use to drain the list
of devices that were already active at the time of registration.
Fields

listener: ClientEnd<DeviceListenerMarker>#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: DeviceListenerRegistryControlHandle
method_type: MethodTypeImplementations
Sourceimpl DeviceListenerRegistryRequest
impl DeviceListenerRegistryRequest
pub fn into_register_listener( self, ) -> Option<(ClientEnd<DeviceListenerMarker>, DeviceListenerRegistryRegisterListenerResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL