pub enum DeviceListenerRequest {
OnDeviceChanged {
event: DeviceEvent,
control_handle: DeviceListenerControlHandle,
},
}Expand description
Callback protocol implemented by clients to receive live device change events.
Events are sent to this listener only for changes occurring after registration is complete.
Variants
OnDeviceChanged
Called when a device change event occurs.
Implementations
Sourceimpl DeviceListenerRequest
impl DeviceListenerRequest
pub fn into_on_device_changed( self, ) -> Option<(DeviceEvent, DeviceListenerControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL