pub struct DeviceIteratorGetNextResponder { /* private fields */ }Implementations
Sourceimpl DeviceIteratorGetNextResponder
impl DeviceIteratorGetNextResponder
Sourcepub fn send(self, devices: &[DeviceEvent]) -> Result<(), Error>
pub fn send(self, devices: &[DeviceEvent]) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
devices: &[DeviceEvent],
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, devices: &[DeviceEvent], ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.