pub struct DeviceIteratorMarker;Trait Implementations
Sourceimpl Clone for DeviceIteratorMarker
impl Clone for DeviceIteratorMarker
Sourcefn clone(&self) -> DeviceIteratorMarker
fn clone(&self) -> DeviceIteratorMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceIteratorMarker
Sourceimpl Debug for DeviceIteratorMarker
impl Debug for DeviceIteratorMarker
impl Eq for DeviceIteratorMarker
Sourceimpl Hash for DeviceIteratorMarker
impl Hash for DeviceIteratorMarker
Sourceimpl Ord for DeviceIteratorMarker
impl Ord for DeviceIteratorMarker
Sourcefn cmp(&self, other: &DeviceIteratorMarker) -> Ordering
fn cmp(&self, other: &DeviceIteratorMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DeviceIteratorMarker
impl PartialEq for DeviceIteratorMarker
Sourceimpl PartialOrd for DeviceIteratorMarker
impl PartialOrd for DeviceIteratorMarker
Sourceimpl ProtocolMarker for DeviceIteratorMarker
impl ProtocolMarker for DeviceIteratorMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) DeviceIterator"
const DEBUG_NAME: &'static str = "(anonymous) DeviceIterator"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = DeviceIteratorProxy
type Proxy = DeviceIteratorProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = DeviceIteratorRequestStream
type RequestStream = DeviceIteratorRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = DeviceIteratorSynchronousProxy
type SynchronousProxy = DeviceIteratorSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for DeviceIteratorMarker