pub struct DeviceIteratorProxy { /* private fields */ }Implementations
Sourceimpl DeviceIteratorProxy
impl DeviceIteratorProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.ui.input/DeviceIterator.
Sourcepub fn take_event_stream(&self) -> DeviceIteratorEventStream
pub fn take_event_stream(&self) -> DeviceIteratorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_next(
&self,
) -> QueryResponseFut<Vec<DeviceEvent>, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_next( &self, ) -> QueryResponseFut<Vec<DeviceEvent>, DefaultFuchsiaResourceDialect> ⓘ
Returns the next batch of active devices.
Returns an empty vector when all existing devices have been iterated
through. The client should then close this channel and rely on the
DeviceListener for subsequent events.