pub struct DeviceIteratorSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DeviceIteratorSynchronousProxy
impl DeviceIteratorSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DeviceIteratorEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceIteratorEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_next(
&self,
___deadline: MonotonicInstant,
) -> Result<Vec<DeviceEvent>, Error>
pub fn get_next( &self, ___deadline: MonotonicInstant, ) -> Result<Vec<DeviceEvent>, Error>
Returns the next batch of active devices.
Returns an empty vector when all existing devices have been iterated
through. The client should then close this channel and rely on the
DeviceListener for subsequent events.