pub struct DeviceListenerOnDeviceChangedRequest {
pub event: DeviceEvent,
}Fields
event: DeviceEventTrait Implementations
Sourceimpl Clone for DeviceListenerOnDeviceChangedRequest
impl Clone for DeviceListenerOnDeviceChangedRequest
Sourcefn clone(&self) -> DeviceListenerOnDeviceChangedRequest
fn clone(&self) -> DeviceListenerOnDeviceChangedRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<DeviceListenerOnDeviceChangedRequest, D> for DeviceListenerOnDeviceChangedRequestwhere
D: ResourceDialect,
impl<D> Decode<DeviceListenerOnDeviceChangedRequest, D> for DeviceListenerOnDeviceChangedRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DeviceListenerOnDeviceChangedRequest
fn new_empty() -> DeviceListenerOnDeviceChangedRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DeviceListenerOnDeviceChangedRequest, D> for &DeviceListenerOnDeviceChangedRequestwhere
D: ResourceDialect,
impl<D> Encode<DeviceListenerOnDeviceChangedRequest, D> for &DeviceListenerOnDeviceChangedRequestwhere
D: ResourceDialect,
impl Persistable for DeviceListenerOnDeviceChangedRequest
impl StructuralPartialEq for DeviceListenerOnDeviceChangedRequest
Sourceimpl TypeMarker for DeviceListenerOnDeviceChangedRequest
impl TypeMarker for DeviceListenerOnDeviceChangedRequest
Sourcetype Owned = DeviceListenerOnDeviceChangedRequest
type Owned = DeviceListenerOnDeviceChangedRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceListenerOnDeviceChangedRequest
impl ValueTypeMarker for DeviceListenerOnDeviceChangedRequest
Sourcetype Borrowed<'a> = &'a DeviceListenerOnDeviceChangedRequest
type Borrowed<'a> = &'a DeviceListenerOnDeviceChangedRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DeviceListenerOnDeviceChangedRequest as TypeMarker>::Owned,
) -> <DeviceListenerOnDeviceChangedRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DeviceListenerOnDeviceChangedRequest as TypeMarker>::Owned, ) -> <DeviceListenerOnDeviceChangedRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DeviceListenerOnDeviceChangedRequest
impl RefUnwindSafe for DeviceListenerOnDeviceChangedRequest
impl Send for DeviceListenerOnDeviceChangedRequest
impl Sync for DeviceListenerOnDeviceChangedRequest
impl Unpin for DeviceListenerOnDeviceChangedRequest
impl UnsafeUnpin for DeviceListenerOnDeviceChangedRequest
impl UnwindSafe for DeviceListenerOnDeviceChangedRequest