pub struct DeviceListenerRegistryRegisterListenerResponder { /* private fields */ }Implementations
Sourceimpl DeviceListenerRegistryRegisterListenerResponder
impl DeviceListenerRegistryRegisterListenerResponder
Sourcepub fn send(
self,
iterator: ClientEnd<DeviceIteratorMarker>,
) -> Result<(), Error>
pub fn send( self, iterator: ClientEnd<DeviceIteratorMarker>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
iterator: ClientEnd<DeviceIteratorMarker>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, iterator: ClientEnd<DeviceIteratorMarker>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.