pub struct DeviceListenerRegistryRegisterListenerResponse {
pub iterator: ClientEnd<DeviceIteratorMarker>,
}Fields
iterator: ClientEnd<DeviceIteratorMarker>Trait Implementations
Sourceimpl Decode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for DeviceListenerRegistryRegisterListenerResponse
impl Decode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for DeviceListenerRegistryRegisterListenerResponse
Sourceimpl Encode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for &mut DeviceListenerRegistryRegisterListenerResponse
impl Encode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for &mut DeviceListenerRegistryRegisterListenerResponse
Sourceimpl<T0: Encode<Endpoint<ClientEnd<DeviceIteratorMarker>>, DefaultFuchsiaResourceDialect>> Encode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Endpoint<ClientEnd<DeviceIteratorMarker>>, DefaultFuchsiaResourceDialect>> Encode<DeviceListenerRegistryRegisterListenerResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl Eq for DeviceListenerRegistryRegisterListenerResponse
Sourceimpl Ord for DeviceListenerRegistryRegisterListenerResponse
impl Ord for DeviceListenerRegistryRegisterListenerResponse
Sourcefn cmp(
&self,
other: &DeviceListenerRegistryRegisterListenerResponse,
) -> Ordering
fn cmp( &self, other: &DeviceListenerRegistryRegisterListenerResponse, ) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for DeviceListenerRegistryRegisterListenerResponse
impl PartialOrd for DeviceListenerRegistryRegisterListenerResponse
Sourcefn partial_cmp(
&self,
other: &DeviceListenerRegistryRegisterListenerResponse,
) -> Option<Ordering>
fn partial_cmp( &self, other: &DeviceListenerRegistryRegisterListenerResponse, ) -> Option<Ordering>
Sourceimpl ResourceTypeMarker for DeviceListenerRegistryRegisterListenerResponse
impl ResourceTypeMarker for DeviceListenerRegistryRegisterListenerResponse
Sourcetype Borrowed<'a> = &'a mut DeviceListenerRegistryRegisterListenerResponse
type Borrowed<'a> = &'a mut DeviceListenerRegistryRegisterListenerResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for DeviceListenerRegistryRegisterListenerResponse
impl StructuralPartialEq for DeviceListenerRegistryRegisterListenerResponse
Sourceimpl TypeMarker for DeviceListenerRegistryRegisterListenerResponse
impl TypeMarker for DeviceListenerRegistryRegisterListenerResponse
Sourcetype Owned = DeviceListenerRegistryRegisterListenerResponse
type Owned = DeviceListenerRegistryRegisterListenerResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for DeviceListenerRegistryRegisterListenerResponse
impl RefUnwindSafe for DeviceListenerRegistryRegisterListenerResponse
impl Send for DeviceListenerRegistryRegisterListenerResponse
impl Sync for DeviceListenerRegistryRegisterListenerResponse
impl Unpin for DeviceListenerRegistryRegisterListenerResponse
impl UnsafeUnpin for DeviceListenerRegistryRegisterListenerResponse
impl UnwindSafe for DeviceListenerRegistryRegisterListenerResponse