pub struct DeviceListenerRegistrySynchronousProxy { /* private fields */ }Implementations
Sourceimpl DeviceListenerRegistrySynchronousProxy
impl DeviceListenerRegistrySynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DeviceListenerRegistryEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceListenerRegistryEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn register_listener(
&self,
listener: ClientEnd<DeviceListenerMarker>,
___deadline: MonotonicInstant,
) -> Result<ClientEnd<DeviceIteratorMarker>, Error>
pub fn register_listener( &self, listener: ClientEnd<DeviceListenerMarker>, ___deadline: MonotonicInstant, ) -> Result<ClientEnd<DeviceIteratorMarker>, Error>
Registers a listener to receive future device change events.
Returns a DeviceIterator which the client MUST use to drain the list
of devices that were already active at the time of registration.